# Philosophy

The core objective is to keep the central mechanism as lean as possible,
allowing users to extend the system through custom templates and user-defined
YAML structures.

# Git 

The commit messages have been standardised to the "Type: Subject" format.  The
  types include Feat, Fix, Docs, Refactor, Chore, Test, Style.
  
For example:
- Feat: Adding --target-list as feature
- Docs: Using docsify.js
- Fix: Fix loader and sets default schema
- Refactor: Rename project structure to quizml



